@@ -48,8 +48,10 @@ def main(token,problem,language,path_to_code):
         submission = requests.get(f'{base_url}/widgets/single_submission?id={submission_num}',headers=headers)
         
         soup1 = BeautifulSoup(submission.text,'html.parser')
+        print(soup1.find(class_='status')['title'],end='')
         
-        if soup1.find(class_='status').text != 'G':
+        if all(x not in soup1.find(class_='status').text for x in ['G','P']):
+            print(':\n')
             testcases = requests.get(f'{base_url}/widgets/submission_testcases?id={submission_num}',headers=headers)
             soup2 = BeautifulSoup(testcases.text,'html.parser')
             cases = soup2.find_all('table')
@@ -65,7 +67,8 @@ def main(token,problem,language,path_to_code):
             print(f'Time: {soup1.find(class_="sub-usage").find(class_="time").text.split()[-1]}')
             
             break
-                
+        print('...')
+        
         time.sleep(1)
         
     
@@ -75,4 +78,11 @@ if __name__ == '__main__':
         print("Helpful help message.")
     else:
         # submit to problem
-        main(sys.argv[1],sys.argv[2],sys.argv[3])
\ No newline at end of file
+        try:
+            f = open('../token','r+')
+        except FileNotFoundError:
+            print("Token file does not exist! Please ensure that your token is configured with `configure` or `-c`")
+            open('../token','w+')
+            sys.exit(1)
+        
+        main(f.read(),sys.argv[1],sys.argv[2],sys.argv[3])
\ No newline at end of file
